//File Description: Create a test bed executable

#include <glib/gstring.h>
#include <gtk/gtk.h>
#include <malloc.h>
#include <memory.h>
#include "Environment.h"
#include "Actions.h"
#include "Config.h"
#include "OSInterface.h"

static void Destroy(GtkWidget *Widget, gpointer Data) { gtk_main_quit(); } //End the application when the window is closed

int main(int argc, char* argv[], char* envp[])
{
	//Init the GTK window
	gtk_init(&argc, &argv);
	GtkWidget *Window=gtk_window_new(GTK_WINDOW_TOPLEVEL);
	g_signal_connect(G_OBJECT(Window), "destroy", G_CALLBACK(Destroy), NULL); //End the application when the window is closed

	InitOSInterface();

	//Save default hot keys
	int NumDefaultSettings;
	const HotKeyAction* DefaultSettings=GetDefaultSettings(&NumDefaultSettings);
	for(int i=0;i<NumDefaultSettings;i++)
	{
		HotKeyAction *CopyAction=(HotKeyAction*)malloc(sizeof(HotKeyAction));
		memcpy(CopyAction, &DefaultSettings[i], sizeof(HotKeyAction));
		if(CopyAction->Type==HKACTIONTYPE_SetStatus)
			CopyAction->Info.Message=g_strdup(CopyAction->Info.Message);
		SaveAction(CopyAction, TRUE);
	}

	//Run the configuration dialog
	GtkWidget *ConfigDialog=LoadConfigDialog();
	gtk_container_add(GTK_CONTAINER(Window), ConfigDialog);
	gtk_widget_show_all(Window);
	gtk_main();

	//Remove all actions
	for(int i=g_list_length(Actions)-1;i>=0;i--)
		DeleteAction(i, FALSE);

	CloseOSInterface();

	return 0;
}

//Process a hot key when it is pressed
void ProcessHotKey(int Identifier)
{
	//Determine which HotKey action was triggered
	int Count=0;
	for(GList *TraverseActions=Actions;TraverseActions;TraverseActions=g_list_next(TraverseActions),Count++)
		if(((HotKeyAction*)TraverseActions->data)->Identifier==Identifier) //When found...
		{
			//Alert the user a hot key was pressed
			HotKeyAction *Action=(HotKeyAction*)TraverseActions->data;
			GString *KeyName=FormatKeyName(Action->Key);
			GString *ActionText=GetActionText(Action);
			GString *FormatText=g_string_new(NULL);
			g_string_printf(FormatText, "%u\n%s\n%s", Count, KeyName->str, ActionText->str);
			ShowDialogBox("Hot key pressed", FormatText->str);
			g_string_free(KeyName, TRUE);
			g_string_free(ActionText, TRUE);
			g_string_free(FormatText, TRUE);
			return;
		}
	ShowDialogBox("Hot key pressed", "Hot key not found");
}

//Unused functions
gboolean    PrefExists    (const char* Name)                   {return FALSE;}
void        PrefsSetBool  (const char* Name, gboolean    Value){}
void        PrefsSetInt   (const char* Name, int         Value){}
void        PrefsSetString(const char* Name, const char* Value){}
gboolean    PrefsGetBool  (const char* Name)                   {return FALSE;}
int         PrefsGetInt   (const char* Name)                   {return 0;    }
const char* PrefsGetString(const char* Name)                   {return NULL; }
void        PrefsRemove   (const char* Name)                   {}
GtkWidget* GetGTKBuddyListWindow(void)                         {return NULL; }
GdkWindow* GetGDKBuddyListWindow(void)                         {return NULL; }
